@@ -367,10 +367,10 @@ def _validate_rules(rules):
     :raises: AnsibleFilterError if any rule is invalid.
     """
     for rule in rules or []:
-        if not isinstance(rule, str):
+        if not isinstance(rule, str) and not isinstance(rule, dict):
             raise errors.AnsibleFilterError(
-                "Routing policy rules must be defined in string format "
-                "for CentOS")
+                "Routing policy rules must be defined in string or dict "
+                "format for CentOS Stream and Rocky Linux")
 
 
 @jinja2.pass_context
